@@ -2,14 +2,20 @@
 """
 CPython 2.4 bytecode opcodes
 
-This is a like Python 2.3's opcode.py with some classification
-of stack usage.
+This is a like Python 2.3's opcode.py with some additional classification
+of stack usage, and opererand formatting functions.
 """
 
 import xdis.opcodes.opcode_2x as opcode_2x
 from xdis.opcodes.base import (
-    def_op, init_opdata,
-    finalize_opcodes, format_extended_arg, update_pj2)
+    def_op,
+    init_opdata,
+    finalize_opcodes,
+    format_CALL_FUNCTION_pos_name_encoded,
+    format_MAKE_FUNCTION_arg,
+    format_extended_arg,
+    update_pj2
+)
 
 version = 2.4
 python_implementation = "CPython"
@@ -29,7 +35,11 @@ def_op(l, 'YIELD_VALUE',          86,  1,  1)
 update_pj2(globals(), l)
 
 opcode_arg_fmt = {
-    'EXTENDED_ARG': format_extended_arg,
+    "CALL_FUNCTION": format_CALL_FUNCTION_pos_name_encoded,
+    "CALL_FUNCTION_KW": format_CALL_FUNCTION_pos_name_encoded,
+    "CALL_FUNCTION_VAR_KW": format_CALL_FUNCTION_pos_name_encoded,
+    "EXTENDED_ARG": format_extended_arg,
+    "MAKE_FUNCTION": format_MAKE_FUNCTION_arg,
 }
 
 finalize_opcodes(l)
