@@ -211,3 +211,10 @@ nargs_op(l, "CALL_FUNCTION_VAR_KW", 142, -3, 1)  # #args + (#kwargs << 8)
 
 def_op(l, "EXTENDED_ARG", 143)
 EXTENDED_ARG = 143
+
+def format_MAKE_FUNCTION_arg(argc):
+    pos_args = argc & 0xFF
+    name_default = (argc >> 8) & 0xFF
+    annotate_args = (argc >> 16) & 0x7FFF
+    return ("%d positional, %d name and default, %d annotations" %
+            (pos_args, name_default, annotate_args))
